@@ -3,7 +3,7 @@
 
 iem_adaptfilt written by Markus Noisternig & Thomas Musil 
 noisternig_AT_iem.at; musil_AT_iem.at
-(c) Institute of Electronic Music and Acoustics, Graz Austria 2005 */
+(c) Institute of Electronic Music and Acoustics, Graz Austria 2018 */
 
 #ifdef NT
 #pragma warning( disable : 4244 )
@@ -28,6 +28,8 @@ void NLMSerr_in_tilde_setup(void);
 void NLMSCC_tilde_setup(void);
 void n_CNLMS_tilde_setup(void);
 void n_CLNLMS_tilde_setup(void);
+void FXNLMSplus2in_tilde_setup(void);
+void FXNLMSplus3in_tilde_setup(void);
 
 /* ------------------------ setup routine ------------------------- */
 
@@ -38,11 +40,13 @@ void iem_adaptfilt_setup(void)
   NLMSCC_tilde_setup();
   n_CNLMS_tilde_setup();
   n_CLNLMS_tilde_setup();
+  FXNLMSplus2in_tilde_setup();
+  FXNLMSplus3in_tilde_setup();
   	
   	post("----------------------------------------------");
-	post("iem_adaptfilt (R-1.02) library loaded!");
+	post("iem_adaptfilt (R-1.03) library loaded!");
 	post("(c) Markus Noisternig, Thomas Musil");
 	post("    {noisternig, musil}_AT_iem.at");
-	post("    IEM Graz, Austria");
+	post("    IEM Graz, Austria, 01.2018");
 	post("----------------------------------------------");
 }
