@@ -450,7 +450,10 @@ static void canvas_triggerize(t_glist*cnv) {
 
 void triggerize_setup(void)
 {
-  if(NULL==canvas_class)return;
+  if(NULL==canvas_class) {
+    verbose(10, "triggerize detected class_new() @ %p", class_new);
+    return;
+  }
   post("triggerize - insert [trigger] ad lib.");
 
   if(NULL==zgetfn(&canvas_class, gensym("triggerize")))
